import request from '@/utils/request'
import { praseStrEmpty } from "@/utils/ruoyi";

// 查询用户列表
export function listUser(query) {
  return request({
    url: '/system/user/list',
    method: 'get',
    params: query
  })
}

// 查询用户详细
export function getUser(userId) {
  return request({
    url: '/system/user/' + praseStrEmpty(userId),
    method: 'get'
  })
}

// 新增用户
export function addUser(data) {
  return request({
    url: '/system/user',
    method: 'post',
    data: data
  })
}

// 新增普通测试用户
export function addTester(data) {
  return request({
    url: '/system/user/addTester',
    method: 'post',
    data: data
  })
}

// 新增普通测试用户
export function changePasswd(data) {
  return request({
    url: '/system/user/changePasswd',
    method: 'post',
    data: data
  })
}

// 修改用户
export function updateUser(data) {
  return request({
    url: '/system/user',
    method: 'put',
    data: data
  })
}

// 删除用户
export function delUser(userId) {
  return request({
    url: '/system/user/' + userId,
    method: 'delete'
  })
}

// 导出用户
export function exportUser(query) {
  return request({
    url: '/system/user/export',
    method: 'get',
    params: query
  })
}

// 用户密码重置
export function resetUserPwd(userId, password) {
  const data = {
    userId,
    password
  }
  return request({
    url: '/system/user/resetPwd',
    method: 'put',
    data: data
  })
}

// 用户状态修改
export function changeUserStatus(userId, status) {
  const data = {
    userId,
    status
  }
  return request({
    url: '/system/user/changeStatus',
    method: 'put',
    data: data
  })
}

// 查询用户个人信息
export function getUserProfile() {
  return request({
    url: '/system/user/profile',
    method: 'get'
  })
}

// 修改用户个人信息
export function updateUserProfile(data) {
  return request({
    url: '/system/user/profile',
    method: 'put',
    data: data
  })
}

// 用户密码重置
export function updateUserPwd(oldPassword, newPassword) {
  const data = {
    oldPassword,
    newPassword
  }
  return request({
    url: '/system/user/profile/updatePwd',
    method: 'put',
    params: data
  })
}

// 用户头像上传
export function uploadAvatar(data) {
  return request({
    url: '/system/user/profile/avatar',
    method: 'post',
    data: data
  })
}

// 下载用户导入模板
export function importTemplate() {
  return request({
    url: '/system/user/importTemplate',
    method: 'get'
  })
}
// 查询用户详细
export function getUserDetail(userId) {
  return request({
    url: '/system/user/detail/' + praseStrEmpty(userId),
    method: 'get'
  })
}
export function list() {
  return request({
    url: '/system/user/listAll',
    method: 'get'
  })
}

// 根据用户编号获取未被审核请求
export function getUnauditInfo(userId) {
  return request({
    url: '/system/user/unaudit/' + praseStrEmpty(userId),
    method: 'get'
  })
}

// 同时更改企业认证和测试认证申请审核状态
export function changeAllStatusOnce(data) {
  return request({
    url: '/system/user/changeAllStatusOnce',
    method: 'put',
    data: data
  })
}

// 根据用户编号获取认证信息
export function getCertifications(userId) {
  return request({
    url: '/system/user/certifications/' + praseStrEmpty(userId),
    method: 'get'
  })
}

// 全局方法和属性 - 开始

// 用户认证状态
export const user_status = createEnum({
  n: [0, '普通用户'],
  c: [1, '公司用户'],
  pt: [2, '个人测试者用户'],
  ct: [3, '测试公司用户'],
})

// 申请类型
export const apple_type = createEnum({
  p2c: [0, '认证公司'],
  p2pt: [1, '认证个人测试者'],
  p2ct: [2, '认证测试公司'],
  c2ct: [3, '认证测试公司'],
  uc: [4, '更新公司'],
  uct: [5, '更新测试公司'],
  upt: [6, '更新个人测试者'],
})

/**
 * 枚举定义工具
 * 示例：
 * const STATUS = createEnum({
 *     AUDIT_WAIT: [1, '审核中'],
 *     AUDIT_PASS: [2, '审核通过']
 * })
 * 获取枚举值：STATUS.AUDIT_WAIT
 * 获取枚举描述：STATUS.getDesc('AUDIT_WAIT')
 * 通过枚举值获取描述：STATUS.getDescFromValue(STATUS.WAIT)
 *
 */
export default function createEnum(definition) {
  const strToValueMap = {}
  const numToDescMap = {}
  for (const enumName of Object.keys(definition)) {
    const [value, desc] = definition[enumName]
    strToValueMap[enumName] = value
    numToDescMap[value] = desc
  }
  return {
    ...strToValueMap,
    getDesc(enumName) {
      return (definition[enumName] && definition[enumName][1]) || ''
    },
    getDescFromValue(value) {
      return numToDescMap[value] || ''
    }
  }
}

// 全局方法和属性 - 结束